@@ -1,18 +1,31 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-"""CLI interface for LetterBomb."""
+# SPDX-License-Identifier: GPL-3.0-or-later
+"""
+CLI interface for ✉️💣 **LetterBomb**.
+
+----
+
+-h, --help            show this help message and exit
+-v, --version         show program's version number and exit
+-b, --bundle          pack the HackMii installer into archive
+-l LOGFILE, --logfile LOGFILE
+                      filepath to put log output
+-g {debug,info,warn,error,critical}, --loglevel {debug,info,warn,error,critical}
+                      minimum logging level
+"""
 import argparse
 import letterbomb
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
     parser.add_argument(
-        "-v", "--version", action="version", version=f"{letterbomb.__proj__} v"
+        "-v", "--version", action="version", version=f"{letterbomb.__project__} v"
                                                      f"{letterbomb.__version__}"
     )
     parser.add_argument("mac", help="string of Wii's MAC address")
     parser.add_argument(
-        "region", choices=["U", "E", "K", "J"], help="single-letter of Wii's region"
+        "region", choices=letterbomb.REGION_LIST, help="single-letter of Wii's region"
     )
     parser.add_argument("outfile", help="filename of ZIP archive")
     parser.add_argument(
@@ -36,6 +49,6 @@ if __name__ == "__main__":
         print(vargs)
     if vargs["logfile"]:
         LOGGING_FILE = letterbomb.pathlib.Path(vargs["logfile"]).expanduser()
-    letterbomb.__main__(
+    letterbomb.write_zip(
         vargs["mac"], vargs["region"], vargs["bundle"], vargs["outfile"]
     )
